@@ -7,7 +7,7 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Tk::CheckListEditor 1.379;
+package Config::Model::Tk::CheckListEditor 1.380;
 
 use strict;
 use warnings;
@@ -113,7 +113,7 @@ sub Populate {
     $cw->ConfigModelNoteEditor( -object => $leaf )->pack(@fbe1);
     $cw->add_summary($leaf)->pack(@fx);
     $cw->add_description($leaf)->pack(@fbe1);
-    my ( $help_frame, $help_widget ) = $cw->add_help( value => '', 1 );
+    my ( $help_frame, $help_widget ) = $cw->add_help( "Value help" => '', 1 );
     $help_frame->pack(@fx);
     $cw->{value_help_widget} = $help_widget;
     $cw->add_info_button()->pack(@fxe1);
